/**
 * MrSDK的回调接口，可继承并重写，传入到sdk的具体函数
 * 或，定义一个具有如下两个函数的对象传入sdk的具体函数
 */
function MrCallback() {
    this.onSuccess = function(responseData){}
    this.onFail = function(mrError) {}
}

window.__mr_platform = 'web'

function postMessage(functionName, params) {

    console.info('call function:' + functionName)

    if(window.__mr_platform === 'ios') {
        window.webkit.messageHandlers[functionName].postMessage(params)
    }else if(window.__mr_platform === 'android') {
        window.mrsdk[functionName](params)
    }
}

function MrSDK() {

    this._lastInitCallback = null
    this._lastLoginCallback = null
    this._lastPayCallback = null
    this._lastLogOutCallback = null
    this._lastRegisterLogout = null

    /////////////sdk接口////////////////////////
    //jssdk初始化接口
    this.init = function (mrInitEntity, callback) {
        this._lastInitCallback = callback
        postMessage('init', JSON.stringify(mrInitEntity))
    }

    //jssdk登陆接口
    this.loginWithUI = function (callback) {
        this._lastLoginCallback = callback
        postMessage('loginWithUI', '')
    }

    //jssdk充值接口
    this.pay = function (mrPayEntity, callback) {
        this._lastPayCallback = callback;
        postMessage('pay', JSON.stringify(mrPayEntity))
    }

    //jssdk登出接口
    this.logOut = function (callback) {
        this._lastLogOut = callback
        postMessage('logOut', '')
    }

    //jssdk注册登出接口
    this.registerLogout = function (callback) {
        this._lastRegisterLogout = callback
        postMessage('registerLogout', '')
    }

    //jssdk发送创角信息
    this.sendRoleCreateData = function (mrRoleEntity) {
        postMessage('sendRoleCreateData', JSON.stringify(mrRoleEntity))
    }

    //jssdkf阿松角色登陆信息
    this.sendRoleLoginData = function (mrRoleEntity) {
        postMessage('sendRoleLoginData', JSON.stringify(mrRoleEntity))
    }


    ///////////////////原生回调接口/////////////////////////
    this.initSdk = function (platform) {
        window.__mr_platform = platform
        return platform
    }

    this.initResult = function (data) {
        alert('initResult: ' + data)
        return this.apiResult(data, this._lastInitCallback)
    }

    //登陆结果
    this.loginWithUIResult = function (data) {
        alert('loginWithUIResult: ' + data)
        return this.apiResult(data, this._lastLoginCallback)
    }

    this.payResult = function (data) {
        return this.apiResult(data, this._lastPayCallback)
    }

    this.logOutResult = function (data) {
        alert('logOutResult: ' + data)
        return this.apiResult(data, this._lastLogOutCallback)
    }

    this.registerLogoutResult = function (data) {
        return this.apiResult(data, this._lastRegisterLogout)
    }

    this.apiResult = function (data, callback) {
        var obj = JSON.parse(data)
        var result = obj.result
        if(callback) {
            if(result === 'success') {
                callback['onSuccess'](obj.data)
            }else {
                callback['onFail'](obj.data)
            }
        }
        return true
    }

    this.callFromNative = function (functionName, params) {
        return this[functionName](params)
    }
}

window.CommonMrSdk = new MrSDK()
